@@ -604,6 +604,7 @@ cal_backend_wcap_events_remove_object (ECalBackendSync *backend, EDataCal *cal,
 	const char *unmangled_uid;
 	guint error_code;
 	char *calobj;
+	char *ridstr;
 	
 	d(printf("cal_backend_wcap_evnets_remove_object(%p, %s, %s)\n", backend, uid, rid));
 
@@ -627,11 +628,14 @@ cal_backend_wcap_events_remove_object (ECalBackendSync *backend, EDataCal *cal,
 
 	sunone_util_unmangle_uid (comp);
 	e_cal_component_get_uid (comp, &unmangled_uid);
-	rid = cal_backend_wcap_get_rid_string (comp);
+	ridstr = cal_backend_wcap_get_rid_string (comp);
 	
-	error_code = sunone_connection_deleteevents_by_id (cal_backend_wcap_get_connection (wcap), cal_backend_wcap_get_calid (wcap),
-								  unmangled_uid, rid, 
-								  cal_backend_wcap_to_sunone_mod (mod, comp));
+	error_code = sunone_connection_deleteevents_by_id (
+			cal_backend_wcap_get_connection (wcap),
+			cal_backend_wcap_get_calid (wcap),
+			unmangled_uid, ridstr,
+			cal_backend_wcap_to_sunone_mod (mod, comp));
+	g_free (ridstr);
 
 	g_object_unref (G_OBJECT (comp));
 
@@ -698,7 +702,8 @@ get_fb_info (SunOneConnection *so_cnc, const char *user, const char *calid, time
 		if (prop != NULL)
 			icalcomponent_add_property (fb, prop);
 
-		*freebusy = g_list_append (*freebusy, g_strdup (icalcomponent_as_ical_string (fb)));
+		*freebusy = g_list_append (*freebusy,
+				icalcomponent_as_ical_string (fb));
 	}
 
 	icalcomponent_free (icalcomp);
