@@ -243,6 +243,7 @@ set_data_and_props (SunOneInvitationList *list, int row)
 	top_level = toplevel_with_zones (list, comp);
 	string = icalcomponent_as_ical_string (top_level);
 	set_data (BONOBO_WIDGET (priv->control), string);
+	g_free (string);
 	icalcomponent_free (top_level);
 }
 
@@ -530,9 +531,13 @@ setup_invitation_list (SunOneInvitationList *list)
 
 	renderer = e_cell_renderer_combo_new ();
 	editable = sunone_util_has_permissions (priv->model->props, 
-				sunone_account_get_user (priv->model->account),
-				SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
-				SUNONE_ACE_PERMISSION_WRITE | SUNONE_ACE_PERMISSION_REPLY);
+					sunone_account_get_user (priv->model->account),
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_WRITE | SUNONE_ACE_PERMISSION_REPLY) ||
+				sunone_util_has_permissions (priv->model->props, 
+					sunone_account_get_uid (priv->model->account),
+					SUNONE_ACE_CONTEXT_CALENDAR_COMPONENTS, 
+					SUNONE_ACE_PERMISSION_WRITE | SUNONE_ACE_PERMISSION_REPLY);
 	g_object_set (G_OBJECT (renderer), "list", strings, "editable", editable, NULL);
 	gtk_tree_view_insert_column_with_attributes (priv->treeview, 
 						-1, 
